@@ -228,11 +228,11 @@ Ted Pedersen, E<lt>tpederse@d.umn.eduE<gt>
 
 =head1 SEE ALSO
 
-L<GoogleHack home page|http://google-hack.sourceforge.net>  
+GoogleHack home page - http://google-hack.sourceforge.net
 
-L<Pratheepan Raveendranathan|http://www.d.umn.edu/~rave0029/research>
+Pratheepan Raveendranathan - http://www.d.umn.edu/~rave0029/research
 
-L<Ted Pedersen|www.d.umn.edu./~tpederse>
+Ted Pedersen - www.d.umn.edu./~tpederse
 
 Google-Hack Maling List E<lt>google-hack-users@lists.sourceforge.netE<gt>
 
@@ -244,7 +244,7 @@ Ted Pedersen, E<lt>tpederse@d.umn.eduE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2003 by Pratheepan Raveendranathan, Ted Pedersen
+Copyright (c) 2005 by Pratheepan Raveendranathan, Ted Pedersen
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
@@ -268,7 +268,7 @@ Boston, MA  02111-1307, USA.
 package WebService::GoogleHack::Text;
 
 
-our $VERSION = '0.09';
+our $VERSION = '0.1';
 
 sub new
 {
